<?php
/**
 * Volcano functions and definitions.
 * Text Domain: volcano
 * When using a child theme (see https://codex.wordpress.org/Theme_Development
 * and https://codex.wordpress.org/Child_Themes), you can override certain
 * functions (those wrapped in a function_exists() call) by defining them first
 * in your child theme's functions.php file. The child theme's functions.php
 * file is included before the parent theme's file, so the child theme
 * functions would be used.
 *
 * For more information on hooks, actions, and filters,
 * see https://codex.wordpress.org/Plugin_API
 *
 * Volcano is a very powerful theme and virtually anything can be customized
 * via a child theme.
 *
 * @package     Volcano
 * @author      Nazmul Hasan
 * @since       volcano 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Volcano_After_Setup_Theme initial setup
 *
 * @since 1.0.0
 */
if ( ! class_exists( 'Volcano_After_Setup_Theme' ) ) {

	/**
	 * Volcano_After_Setup_Theme initial setup
	 */
	class Volcano_After_Setup_Theme {

		/**
		 * Instance
		 *
		 * @var $instance
		 */
		private static $instance;

		/**
		 * Initiator
		 *
		 * @since 1.0.0
		 * @return object
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {
			add_action( 'after_setup_theme', array( $this, 'setup_theme' ), 2 );
			add_action( 'wp', array( $this, 'setup_content_width' ) );
		}

		/**
		 * Setup theme
		 *
		 * @since 1.0.0
		 */
		public function setup_theme() {

			do_action('volcano_class_loaded' );

			/**
			 * Make theme available for translation.
			 * Translations can be filed in the /languages/ directory.
			 * If you're building a theme based on Next, use a find and replace
			 * to change 'volcano' to the name of your theme in all the template files.
			 */
			load_theme_textdomain( 'volcano', VOLCANO_THEME_DIR . '/languages' );

			/**
			 * Theme Support
			 */

			// Gutenberg wide images.
			add_theme_support( 'align-wide' );

			// Add default posts and comments RSS feed links to head.
			add_theme_support( 'automatic-feed-links' );

			// Let WordPress manage the document title.
			add_theme_support( 'title-tag' );

			// Enable support for Post Thumbnails on posts and pages.
			add_theme_support( 'post-thumbnails' );

			// Switch default core markup for search form, comment form, and comments.
			// to output valid HTML5.
			// Added a new value in HTML5 array 'navigation-widgets' as this was introduced in WP5.5 for better accessibility.
			add_theme_support(
				'html5',
				array(
					'navigation-widgets',
					'search-form',
					'gallery',
					'caption',
					'style',
					'script',
				)
			);

			// Post formats.
			add_theme_support(
				'post-formats',
				array(
					'gallery',
					'image',
				)
			);

			// Add theme support for Custom Logo.
			add_theme_support(
				'custom-logo',
				array(
					'width'       => 180,
					'height'      => 60,
					'flex-width'  => true,
					'flex-height' => true,
				)
			);

			// Set up the WordPress core custom background feature.
			add_theme_support( 'custom-background', apply_filters( 'volcano_custom_background_args', [
				'default-color' => 'ffffff',
				'default-image' => '',
			] ) );

			// Set up the WordPress core custom header feature.
			add_theme_support( 'custom-header', [
				'wp-head-callback'       => '',
				'admin-head-callback'    => '',
				'admin-preview-callback' => '',
			] );

			// Add support for Block Styles.
			add_theme_support( 'wp-block-styles' );


			// Add support for responsive embedded content.
			add_theme_support( 'responsive-embeds' );

			// Customize Selective Refresh Widgets.
			add_theme_support( 'customize-selective-refresh-widgets' );

			// WooCommerce.
			add_theme_support( 'woocommerce' );

		}

		/**
		 * Set the $content_width global variable used by WordPress to set image dimensions.
		 *
		 * @since 1.5.5
		 * @return void
		 */
		public function setup_content_width() {

		}

	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
Volcano_After_Setup_Theme::get_instance();
