<?php
/**
 * Loader Functions
 *
 * @package     Volcano
 * @author      Nazmul Hasan
 * @since       volcano 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Theme Enqueue Scripts
 */
if ( ! class_exists( 'Volcano_Enqueue_Scripts' ) ) {

	/**
	 * Theme Enqueue Scripts
	 */
	class Volcano_Enqueue_Scripts {

		/**
		 * Constructor
		 */
		public function __construct() {
			add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ], 1 );
			add_action( 'enqueue_block_editor_assets', [ $this, 'gutenberg_assets' ]  );
			add_action( 'admin_init', [ $this, 'volcano_add_editor_styles' ] );
		}


		/**
		 * Enqueue Scripts
		 */
		public function enqueue_scripts() {

			// Enqueue required styles.
			wp_enqueue_style( 'volcano-bootstrap', VOLCANO_THEME_URI . 'assets/dist/css/bootstrap.css', [], VOLCANO_THEME_VERSION );
			wp_enqueue_style( 'volcano-themify-icons', VOLCANO_THEME_URI . 'assets/plugins/themify-icons/themify-icons.css', [], VOLCANO_THEME_VERSION );
			wp_enqueue_style( 'volcano-superfish', VOLCANO_THEME_URI . 'assets/plugins/superfish/css/superfish.css', [], VOLCANO_THEME_VERSION );
			wp_enqueue_style( 'volcano', VOLCANO_THEME_URI . 'assets/dist/css/volcano.css', [], VOLCANO_THEME_VERSION );

			// Enqueue required scripts.
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-masonry' );
			wp_enqueue_script( 'volcano-superfish', VOLCANO_THEME_URI . 'assets/plugins/superfish/js/superfish.min.js', [ 'jquery' ], VOLCANO_THEME_VERSION, true );
			wp_enqueue_script( 'volcano', VOLCANO_THEME_URI . 'assets/dist/js/volcano-main.js', [ 'jquery' ], VOLCANO_THEME_VERSION, true );

		}

		/**
		 * Enqueue Gutenberg assets.
		 *
		 * @since 1.5.2
		 *
		 * @return void
		 */
		public function gutenberg_assets() {

		}

		/**
		 * Editor style
		 *
		 * @since 1.0.0
		 *
		 * @return void
		 */
		public function volcano_add_editor_styles() {
			add_editor_style( VOLCANO_THEME_URI . 'assets/dist/css/style-editor.css');
		}
	}

	new Volcano_Enqueue_Scripts();
}
